/// <reference types="react" />
import typographyTokens from '@highlight-ui/tokens/dist/typography/typography.json';
import typographyColorTokens from '@highlight-ui/tokens/dist/typography/colors.json';
import typographyFontFamilyTokens from '@highlight-ui/tokens/dist/typography/fontFamilies.json';
import typographyFontSizeTokens from '@highlight-ui/tokens/dist/typography/fontSizes.json';
import typographyFontWeightTokens from '@highlight-ui/tokens/dist/typography/fontWeights.json';
import typographyTextCaseTokens from '@highlight-ui/tokens/dist/typography/textCase.json';
import typographyTextDecorationTokens from '@highlight-ui/tokens/dist/typography/textDecoration.json';
import typographyLetterSpacingTokens from '@highlight-ui/tokens/dist/typography/letterSpacing.json';
import typographyLineHeightTokens from '@highlight-ui/tokens/dist/typography/lineHeights.json';
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
export declare type TypographyToken = keyof typeof typographyTokens;
export declare type TypographyColorToken = keyof typeof typographyColorTokens;
export declare type TypographyFontFamilyToken = keyof typeof typographyFontFamilyTokens;
export declare type TypographyFontSizeToken = keyof typeof typographyFontSizeTokens;
export declare type TypographyFontWeightToken = keyof typeof typographyFontWeightTokens;
export declare type TypographyTextCaseToken = keyof typeof typographyTextCaseTokens;
export declare type TypographyTextDecorationToken = keyof typeof typographyTextDecorationTokens;
export declare type TypographyLetterSpacingToken = keyof typeof typographyLetterSpacingTokens;
export declare type TypographyLineHeightToken = keyof typeof typographyLineHeightTokens;
declare type TypographyAsProps = 'h1' | 'h2' | 'h3' | 'h4' | 'h5' | 'h6' | 'p' | 'span';
export declare type BaseTypographyProps = React.PropsWithChildren<{
    /** Specifies an HTML tag for rendering the element */
    as?: TypographyAsProps;
    /** Specifies font family */
    fontFamily?: TypographyFontFamilyToken;
    /** Specifies font size */
    fontSize?: TypographyFontSizeToken;
    /** Specifies font weight */
    fontWeight?: TypographyFontWeightToken;
    /** Specifies letter spacing */
    letterSpacing?: TypographyLetterSpacingToken;
    /** Specifies line height */
    lineHeight?: TypographyLineHeightToken;
    /** Specifies text case */
    textTransform?: TypographyTextCaseToken;
    /** Specifies text decoration */
    textDecoration?: TypographyTextDecorationToken;
    /** Specifies a text color */
    color?: TypographyColorToken;
}>;
/**
 * @deprecated this type is deprecated and will be removed in future releases.
 * @deprecated This type is deprecated and will be removed in future releases.
 * Please use `HeadingProps` or `BodyProps` instead.
 */
export declare type TokenisedTypographyProps = PropsWithMetadata<{
    /** Specifies typography token (Ignores `variant` if specified) */
    token: TypographyToken;
    /** Specifies font family (Ignored if `variant` is specified) */
    fontFamily?: TypographyFontFamilyToken;
    /** Specifies font size (Ignored if `variant` is specified) */
    fontSize?: TypographyFontSizeToken;
    /** Specifies font weight (Ignored if `variant` is specified) */
    fontWeight?: TypographyFontWeightToken;
    /** Specifies letter spacing (Ignored if `variant` is specified) */
    letterSpacing?: TypographyLetterSpacingToken;
    /** Specifies line height (Ignored if `variant` is specified) */
    lineHeight?: TypographyLineHeightToken;
    /** Specifies text case (Ignored if `variant` is specified) */
    textTransform?: TypographyTextCaseToken;
    /** Specifies text decoration (Ignored if `variant` is specified) */
    textDecoration?: TypographyTextDecorationToken;
}> & React.PropsWithChildren<{
    /** Allows providing a custom class name */
    className?: string;
    /** Specifies an HTML tag for rendering the element */
    component?: string;
    /** Specifies a color of the typography */
    color?: TypographyColorToken;
}> & React.HTMLAttributes<HTMLElement> & React.ButtonHTMLAttributes<HTMLElement>;
/**
 * @deprecated This type is deprecated and will be removed in future releases.
 * Please use `HeadingProps` or `BodyProps` instead.
 */
export declare type TypographyProps = TokenisedTypographyProps;
export declare type BodyVariant = 'large' | 'base' | 'small' | 'strong-large' | 'strong-base' | 'strong-small';
export declare type HeadingVariant = '2xlarge' | 'xlarge' | 'large' | 'medium' | 'small' | 'xsmall';
export declare type BodyProps = React.PropsWithChildren<{
    /** Specifies the variant of body */
    variant?: BodyVariant;
    /** Specifies an HTML tag for rendering the body element */
    as?: Extract<TypographyAsProps, 'p' | 'span'>;
} & Pick<BaseTypographyProps, 'color'>>;
export declare type HeadingProps = React.PropsWithChildren<{
    /** Specifies the variant of the heading */
    variant?: HeadingVariant;
    /** Specifies an HTML tag for rendering the heading element */
    as?: Exclude<TypographyAsProps, 'p' | 'span'>;
} & Pick<BaseTypographyProps, 'color'>>;
export declare type BodyVariantProps = Record<BodyVariant, {
    fontSize: TypographyFontSizeToken;
    lineHeight: TypographyLineHeightToken;
    fontWeight: TypographyFontWeightToken;
}>;
export declare type HeadingVariantProps = Record<HeadingVariant, {
    fontSize: TypographyFontSizeToken;
    lineHeight: TypographyLineHeightToken;
}>;
export {};
